==> easyviper.extended.behaviours.package.debug-1.1-sources.jar: com/ebmwebsourcing/easyviper/core/extended/behaviours/_package/debug/impl/LoggerBehaviourImpl.java <==
package com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.impl;

import java.util.Calendar;
import java.util.Map;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Requires;
import org.objectweb.fractal.fraclet.types.Contingency;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.Node;
import com.ebmwebsourcing.easyviper.core.api.engine.expression.StringExpression;
import com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api.LoggerBehaviour;



@org.objectweb.fractal.fraclet.annotations.Component(provides = @Interface(name = "service", signature = LoggerBehaviour.class))
public class LoggerBehaviourImpl extends EchoBehaviourImpl implements LoggerBehaviour {


	private static final long serialVersionUID = 1L;

	private Logger log = Logger.getLogger(BreakpointBehaviourImpl.class
			.getName());

	@Requires(name = "node", contingency = Contingency.OPTIONAL)
	protected Node node;


	private LEVEL level;


	public LoggerBehaviourImpl(){
		
	}

	public LEVEL getLevel() {
		return this.level;
	}


	public void setLevel(LEVEL level) {
		this.level = level;

	}

	public void severe(String msg) {
		this.log.severe("[BPEL] "+Calendar.getInstance().getTime().toString()+" "+msg);

	}

	public void warning(String msg) {
		this.log.warning("[BPEL]  "+Calendar.getInstance().getTime().toString()+" "+msg);

	}

	public void info(String msg) {
		this.log.info("[BPEL] "+Calendar.getInstance().getTime().toString()+" "+msg);

	}

	public void debug(String msg) {
		this.log.info("[BPEL] "+Calendar.getInstance().getTime().toString()+" "+msg);

	}


	@Override
	public void executeActivity() throws CoreException {

		String msg = this.getMessage().evaluate(this.node.getExecution().getParentScope());
		
		if(this.level == null){
			severe("Level is null !" + msg);
		}else 
		 if(this.level.equals(LoggerBehaviour.LEVEL.SEVERE)){
			severe(msg);
		}else if(this.level.equals(LoggerBehaviour.LEVEL.WARNING)){
			warning(msg);
		}else if(this.level.equals(LoggerBehaviour.LEVEL.INFO)){
			info(msg);
		}else if(this.level.equals(LoggerBehaviour.LEVEL.DEBUG)){
			debug(msg);
		}


	}


	@Override
	public Node getNode() {
		return this.node;
	}




	@Override
	public String toString() {
		return "LoggerActivity";
	}
	
	@Override
	public Map<String, Object> getInitializationContext()
	throws CoreException {
		super.getInitializationContext();
		context.put("message", this.getMessage());
		context.put("level", this.getLevel());
		return context;
	}

	@Override
	public void setInitializationContext(final Map<String, Object> context)
	throws CoreException {
		this.context.put("message", context.get("message"));
		this.context.put("level", context.get("level"));
		this.setMessage((StringExpression<?>) context.get("message"));
		this.setLevel((LEVEL)context.get("level"));
		
	}


}

==> easyviper.extended.behaviours.package.debug-1.3-sources.jar: com/ebmwebsourcing/easyviper/core/extended/behaviours/_package/debug/impl/LoggerBehaviourImpl.java <==
package com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.impl;

import java.util.Calendar;
import java.util.Map;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Requires;
import org.objectweb.fractal.fraclet.types.Contingency;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.Node;
import com.ebmwebsourcing.easyviper.core.api.engine.expression.StringExpression;
import com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api.LoggerBehaviour;



@org.objectweb.fractal.fraclet.annotations.Component(provides = @Interface(name = "service", signature = LoggerBehaviour.class))
public class LoggerBehaviourImpl extends EchoBehaviourImpl implements LoggerBehaviour {


	private static final long serialVersionUID = 1L;

	private Logger log = Logger.getLogger(BreakpointBehaviourImpl.class
			.getName());

	@Requires(name = "node", contingency = Contingency.OPTIONAL)
	protected Node node;


	private LEVEL level;


	public LoggerBehaviourImpl(){
		
	}

	public LEVEL getLevel() {
		return this.level;
	}


	public void setLevel(LEVEL level) {
		this.level = level;

	}

	public void severe(String msg) {
		this.log.severe("[BPEL] "+Calendar.getInstance().getTime().toString()+" "+msg);

	}

	public void warning(String msg) {
		this.log.warning("[BPEL]  "+Calendar.getInstance().getTime().toString()+" "+msg);

	}

	public void info(String msg) {
		this.log.info("[BPEL] "+Calendar.getInstance().getTime().toString()+" "+msg);

	}

	public void debug(String msg) {
		this.log.info("[BPEL] "+Calendar.getInstance().getTime().toString()+" "+msg);

	}


	@Override
	public Node getNode() {
		return this.node;
	}




	@Override
	public String toString() {
		return "LoggerActivity";
	}
	
	@Override
	public Map<String, Object> getInitializationContext()
	throws CoreException {
		super.getInitializationContext();
		context.put("message", this.getMessage());
		context.put("level", this.getLevel());
		return context;
	}

	@Override
	public void setInitializationContext(final Map<String, Object> context)
	throws CoreException {
		this.context.put("message", context.get("message"));
		this.context.put("level", context.get("level"));
		this.setMessage((StringExpression<?>) context.get("message"));
		this.setLevel((LEVEL)context.get("level"));
		
	}

	
	@Override
	protected void executeOnInactive() throws CoreException {
		String msg = this.getMessage().evaluate(this.node.getExecution().getParentScope());
		
		if(this.level == null){
			severe("Level is null !" + msg);
		}else 
		 if(this.level.equals(LoggerBehaviour.LEVEL.SEVERE)){
			severe(msg);
		}else if(this.level.equals(LoggerBehaviour.LEVEL.WARNING)){
			warning(msg);
		}else if(this.level.equals(LoggerBehaviour.LEVEL.INFO)){
			info(msg);
		}else if(this.level.equals(LoggerBehaviour.LEVEL.DEBUG)){
			debug(msg);
		}
	}	

}
